@@ -7,15 +7,17 @@ use base qw/File::Assets::Filter::Minifier/;
 use Carp::Clan qw/^File::Assets/;
 
 my $minifier = "CSS::Minifier";
+my $available = eval "require $minifier;";
+
 sub new {
     my $class = shift;
-    croak "You need to install $minifier to use this filter: $class" unless eval "require $minifier";
+    croak "You need to install $minifier to use this filter: $class" unless $available;
     return $class->SUPER::new(@_);
 }
 
-__PACKAGE__->_type(File::Assets::Util->parse_type("css"));
-__PACKAGE__->_minifier(sub {
-    CSS::Minifier::minify(input => shift, outfile => shift);
-});
+sub minify {
+    return CSS::Minifier::minify(input => shift, outfile => shift);
+}
+__PACKAGE__->_minifier(\&minify);
 
 1;
